import controlP5.*;

ControlP5 cp5;

PImage src;

// The additional width needed on the screen to
// accommodate all the UI controls.
int control_width = 250;

// The background colour to use in the control area.
int bg_colour = color( 100, 100, 100 );

// The current brush diameter.
float diameter;
// The current brush opacity.
float opacity;

// A flag to keep track of whether we're currently
// using the brush.  (You'd think that we could just
// use the built-in mousePressed variable, but we
// need to check whether we're pressing the mouse inside
// the control area or inside the painting area.)
boolean painting;

Button quit_button;

void setup()
{
  src = loadImage( "image.jpg" );
  // Load the image first.  *Now* set the size of the 
  // sketch window to accommodate the image and the
  // controls.
  size( src.width + control_width, src.height );
  background( 255 );
  noStroke();
  
  opacity = 0.6;
  diameter = 50;

  drawControlRect();

  // Now set up the user interface.  First create a ControlP5
  // object that manages all UI elements.
  cp5 = new ControlP5( this );

  // Now create all the UI elements one by one.
  quit_button = cp5.addButton( "Quit" )
    .setPosition( src.width + control_width/2 - 25, height/2 )
    .setSize( 50, 30 );
    
  painting = false;
}

void drawControlRect()
{
  fill( bg_colour );
  rect( src.width, 0, control_width, height );
}

void draw()
{
  if ( painting ) {
    fill( src.get( mouseX, mouseY ), opacity * 255.0 );
    ellipse( mouseX, mouseY, diameter, diameter );
  }

  drawControlRect();
}

void mousePressed()
{
  // Only start painting if we're in the painting area.
  // If we're in the control area, let ControlP5 decide if
  // we're interacting with a widget.
  painting = (mouseX < src.width);
}

void mouseReleased()
{
  painting = false;
}

// Save just the painted part of the screen, and not the
// control area too.  Do this with the help of Processing's
// get() function.
void savePainting( String fname )
{
  PImage out = get( 0, 0, src.width, src.height );
  out.save( fname );
}

void controlEvent( ControlEvent ev )
{
  if( ev.isFrom( quit_button ) ) {
    exit();
  }
}
